| Title: | Fitting Functional Responses in 1- and 2-Prey Systems |
|---|---|
| Description: | Easy application of Bayesian inference for functional responses via 'brms'. This package allows to fit various FR models for single- and multi-prey experiments by providing nonlinear prediction functions for 'brms'. It uses dynamical prediction models to correct for prey depletion. The 'brms' framework facilitates statistical modeling and enables users to conveniently incorporate covariates such as temperature gradients, experimental treatment variables, or random effects that account for grouping in experimental units. Default 'brms' functions make it easy to perform model checking, model comparison and hypothesis testing. Potential statistical issues with data from feeding trials, such as overdispersion, can be resolved by effortlessly switching between likelihood functions. This package, together with its tutorials, should provide students and researchers with a comprehensive and integrated statistical framework for easily testing their hypotheses on trophic interactions. References: Rosenbaum and Rall (2018) <doi:10.1111/2041-210X.13039>; Rosenbaum et al. (2024) <doi:10.1111/2041-210X.14372>. |
| Authors: | Benjamin Rosenbaum [aut, cre] (ORCID: <https://orcid.org/0000-0002-2815-0874>) |
| Maintainer: | Benjamin Rosenbaum <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.1 |
| Built: | 2026-06-24 09:30:40 UTC |
| Source: | https://github.com/benjamin-rosenbaum/bayesfr |
brms requires univariate response values here. Transforms one row with bivariate (NE1,NE2) to two rows with NE=NE1 and NE=NE2, respectively. Species identity of focal prey is saved in column ID, initial abundance of focal prey in column N0, and initial abundance of non-focal, alternative prey in column N0.alt
convert_2sp_to_long(df)convert_2sp_to_long(df)
df |
data frame with at least these columns named: N01, N02, NE1, NE2 |
The transformed data frame
Feeding experiment data from Archer et al. (2019a) were downloaded from Dryad (Archer et al. 2019b). Eaten prey were not replaced during the experiment. Includes data for housefly larvae (Limnophora riparia) and caddisfly larva (Potamophylax cingulatus) feeding on blackfly larvae (Simuliidae). Due to prey background mortality, control experiments without predators were performed, too. Includes a temperature gradient and data from 2 settings (lab/field) and from 2 years.
data(df_Archer_et_al_2019_JAE)data(df_Archer_et_al_2019_JAE)
A data frame with 580 rows and 9 variables:
Number of initial prey
Number of eaten prey
Number of predators (0 or 1)
Duration (h)
Predator species or control
Prey species
Experimental temperature
laboratory or field
2013 or 2015
Archer L. C., Sohlström E. H., Gallo B., Jochum M., Woodward G., Kordas R. L., Rall B. C. & O'Gorman E. J. (2019a). Consistent temperature dependence of functional response parameters and their use in predicting population abundance. Journal of Animal Ecology, 88:1670-1683. https://doi.org/10.1111/1365-2656.13060
Archer L. C., Sohlström E. H., Gallo B., Jochum M., Woodward G., Kordas R. L., Rall B. C. & O'Gorman E. J. (2019b). Consistent temperature dependence of functional response parameters and their use in predicting population abundance. Dryad Digital Repository. https://doi.org/10.5061/dryad.tr4v447
data(df_Archer_et_al_2019_JAE) head(df_Archer_et_al_2019_JAE)data(df_Archer_et_al_2019_JAE) head(df_Archer_et_al_2019_JAE)
Feeding experiment data from Colton (1987) were downloaded from Figshare (Novak & Stouffer 2020). Eaten prey were not replaced during the experiment. Includes data for 10th???instar naiads of a damselfly feeding on a cladoceran (Simocephalus serrulatus, species 1) and a copepod (Diaptomus spatulocrenatus, species 2).
data(df_Colton_1987_1_ECOLOGY)data(df_Colton_1987_1_ECOLOGY)
A data frame with 108 rows and 6 variables:
Number of initial prey, species 1
Number of initial prey, species 2
Number of eaten prey, species 1
Number of eaten prey, species 2
Number of predators (1)
Duration (h)
A single typo (720) was corrected (120).
Colton, T.F. (1987). Extending functional response models to include a second prey type: an experimental test. Ecology, 68: 900-912. https://doi.org/10.2307/1938361
Novak, M., & Stouffer, D. (2020). Data extracted for "Hidden layers of density dependence in consumer feeding rates." Figshare. https://doi.org/10.6084/m9.figshare.12830792
data(df_Colton_1987_1_ECOLOGY) head(df_Colton_1987_1_ECOLOGY)data(df_Colton_1987_1_ECOLOGY) head(df_Colton_1987_1_ECOLOGY)
Feeding experiment data from Cuthbert et al. (2020a) were downloaded from Dryad (Cuthbert et al. 2020b). Eaten prey were not replaced during the experiment. Includes data for two fish species (largemouth bass and bluegill) feeding on tilapia. Both predator and prey were categorized in three size classes, each, with a full factorial treatment.
data(df_Cuthbert_et_al_2020_ECOL_EVOL)data(df_Cuthbert_et_al_2020_ECOL_EVOL)
A data frame with 358 rows and 7 variables:
Number of initial prey
Number of eaten prey
Duration (h)
Predator species
Prey species
Predator size class
Prey size class
Cuthbert R. N., Wassermann R. J., Dalu T., Kaiser H., Weyl O. L. F., Dick J. T. A., Sentis A., McCoy M. W., & Alexander M.E. (2020a). *Influence of intra- and interspecific variation in predator-prey body size ratios on trophic interaction strengths. Ecology and Evolution, 10:5946-5962. https://doi.org/10.1002/ece3.6332
Cuthbert R. N., Wassermann R. J., Dalu T., Kaiser H., Weyl O. L. F., Dick J. T. A., Sentis A., McCoy M. W., & Alexander M.E. (2020b). Influence of intra- and interspecific variation in predator-prey body size ratios on trophic interaction strengths. Dryad Digital Repository. https://doi.org/10.5061/dryad.7m0cfxppt
data(df_Cuthbert_et_al_2020_ECOL_EVOL) head(df_Cuthbert_et_al_2020_ECOL_EVOL)data(df_Cuthbert_et_al_2020_ECOL_EVOL) head(df_Cuthbert_et_al_2020_ECOL_EVOL)
Feeding experiment data from Davidson et al. (2021) were downloaded from Dryad (Davidson et al. 2020). Eaten prey were not replaced during the experiment. Includes data for two dragonfly nymph species (Pachydiplax and Erythemis) feeding on mosquito larvae. Experiments were performed on a temperature gradient, and predator size was measured, too.
data(df_Davidson_et_al_2021_FUN_ECOL)data(df_Davidson_et_al_2021_FUN_ECOL)
A data frame with 91 rows and 7 variables:
Number of initial prey
Number of eaten prey
Duration (h)
Predator species
Prey species
Experimental temperature
Predator size
Davidson A. T., Hamman, E. A., McCoy M. W., and Vonesh J. R. (2021). Asymmetrical effects of temperature on stage-structured predator-prey interactions. Functional Ecology 35: 1041-1054. https://doi.org/10.1111/1365-2435.13777
Davidson A. T., Hamman, E. A., McCoy M. W., and Vonesh J. R. (2020). Asymmetrical effects of temperature on stage-structured predator-prey interactions. Dryad Digital Repository. https://doi.org/10.5061/dryad.j6q573nd4
data(df_Davidson_et_al_2021_FUN_ECOL) head(df_Davidson_et_al_2021_FUN_ECOL)data(df_Davidson_et_al_2021_FUN_ECOL) head(df_Davidson_et_al_2021_FUN_ECOL)
Feeding experiment data from Hossie and Murray (2010) downloaded from the FoRAGE database (Uiterwaal et al. 2022). Eaten prey were not replaced during the experiment. Includes data for a dragonfly nymph predator feeding on tadpoles in three leaf litter treatments.
data(df_Hossie_and_Murray_2010_OECOLOGIA)data(df_Hossie_and_Murray_2010_OECOLOGIA)
A data frame with 91 rows and 6 variables:
Number of initial prey
Number of eaten prey
Duration (h)
Predator species
Prey species
Leaf litter treatment
Hossie T. J. and Murray D. S. (2010). You can't run but you can hide: refuge use in frog tadpoles elicits density-dependent predation by dragonfly larvae. Oecologia, 163, 395-404. https://doi.org/10.1007/s00442-010-1568-6
Uiterwaal S. F., Lagerstrom I. T., Lyon S. R., and DeLong, J. P. (2022). FoRAGE Database: A Compilation of Functional Responses for Consumers and Parasitoids. Ecology 103(7): e3706. https://doi.org/10.1002/ecy.3706
FoRAGE database V5 (2024). https://doi.org/10.5063/F1RX99KB
data(df_Hossie_and_Murray_2010_OECOLOGIA) head(df_Hossie_and_Murray_2010_OECOLOGIA)data(df_Hossie_and_Murray_2010_OECOLOGIA) head(df_Hossie_and_Murray_2010_OECOLOGIA)
Feeding experiment data from Michalko and Pekar (2017) downloaded from the FoRAGE database (Uiterwaal et al. 2022). Eaten prey were replaced during the experiment. Includes three predator-prey combinations with a top predator (Philodromus buchari), a mesopredator (Dictyna spp.) and a pest (C. pyri).
data(df_Michalko_and_Pekar_2017_AM_NAT)data(df_Michalko_and_Pekar_2017_AM_NAT)
A data frame with 63 rows and 6 variables:
Number of constant prey
Number of eaten prey
Duration (h)
Predator species
Prey species
Predator-prey combination
Michalko R. and Pekar S. (2017). The Behavioral Type of a Top Predator Drives the Short-Term Dynamic of Intraguild Predation. American Naturalist, 189, 242-253. https://doi.org/10.1086/690501
Uiterwaal S. F., Lagerstrom I. T., Lyon S. R., and DeLong, J. P. (2022). FoRAGE Database: A Compilation of Functional Responses for Consumers and Parasitoids. Ecology 103(7): e3706. https://doi.org/10.1002/ecy.3706
FoRAGE database V5 (2024). https://doi.org/10.5063/F1RX99KB
data(df_Michalko_and_Pekar_2017_AM_NAT) head(df_Michalko_and_Pekar_2017_AM_NAT)data(df_Michalko_and_Pekar_2017_AM_NAT) head(df_Michalko_and_Pekar_2017_AM_NAT)
Feeding experiment data from Papanikolaou et al. (2021a) downloaded from Dryad (Papanikolaou et al. 2021b). Eaten prey were not replaced during the experiment. Includes data for two mirid predators (1st and 5th instar nymphs) feeding on Pyralidae eggs. Includes four predator treatments with 1,2,3 or 4 predators, each.
data(df_Papanikolaou_et_al_2021_ECOL_EVOL)data(df_Papanikolaou_et_al_2021_ECOL_EVOL)
A data frame with 327 rows and 7 variables:
Number of initial prey
Number of eaten prey
Number of predator individuals
Duration (h)
Predator species
Prey species
1st or 5th instar nymphs
Papanikolaou N.E., Dervisoglou S., Fantinou A., Kypraios T., Giakoumaki V., Perdikis D. (2021a). Predator size affects the intensity of mutual interference in a predatory mirid. Ecology and Evolution 2021(11): 1342???1351. https://doi.org/10.1002/ece3.7137
Papanikolaou N.E., Dervisoglou S., Fantinou A., Kypraios T., Giakoumaki V., Perdikis D. (2021b). Data from: Predator size affects the intensity of mutual interference in a predatory mirid. Dryad https://doi.org/10.5061/dryad.2ngf1vhmj
data(df_Papanikolaou_et_al_2021_ECOL_EVOL) head(df_Papanikolaou_et_al_2021_ECOL_EVOL)data(df_Papanikolaou_et_al_2021_ECOL_EVOL) head(df_Papanikolaou_et_al_2021_ECOL_EVOL)
Feeding experiment data from Schr??der et al. (2016) were downloaded from Figshare (Kalinkat et al. 2025) under CC BY 4.0. Eaten prey were not replaced during the experiments (2 minutes). Includes data for least killifish (Heterandria formosa, 49 individuals) feeding on nauplii (Artemia salina). Predator individuals were re-used and predator ID was recorded for each trial. Also includes predator size.
data(df_Schroeder_et_al_2016_OEC)data(df_Schroeder_et_al_2016_OEC)
A data frame with 686 rows and 8 variables:
Number of initial prey
Number of eaten prey
Duration (h): 2 min
Predator individual ID
Predator individual size (mm)
Predator species
Prey species
Trials performed in the morning or evening
Schröder A., Kalinkat G. & Arlinghaus R. (2016). Individual variation in functional response parameters is explained by body size but not by behavioural types in a poeciliid fish. Oecologia, 88:1670???1683. https://doi.org/10.1007/s00442-016-3701-7
Kalinkat G., Schröder A. & Arlinghaus R. (2025). Individual variation in functional response parameters is explained by body size but not by behavioural types in a poeciliid fish. Figshare. https://doi.org/10.6084/m9.figshare.24665880
data(df_Schroeder_et_al_2016_OEC) head(df_Schroeder_et_al_2016_OEC)data(df_Schroeder_et_al_2016_OEC) head(df_Schroeder_et_al_2016_OEC)
Feeding experiment data from Sentis et al. (2017) downloaded from the FoRAGE database (Uiterwaal et al. 2022). Eaten prey were not replaced during the experiment. Includes data for three aquatic insect larvae predators feeding on Daphnia prey in two temperature treatments.
data(df_Sentis_et_al_2017_GLOBAL_CHANGE_BIOLOGY)data(df_Sentis_et_al_2017_GLOBAL_CHANGE_BIOLOGY)
A data frame with 327 rows and 7 variables:
Number of initial prey
Number of eaten prey
Duration (h)
Predator species
Prey species
Predator-Temperature combination
Temperature treatment
Sentis A., Gemard C., Jaugeon B., and Boukal D. S. (2017). Predator diversity and environmental change modify the strengths of trophic and nontrophic interactions. Global Change Biology, 23: 2629-2640. https://doi.org/10.1111/gcb.13560
Uiterwaal S. F., Lagerstrom I. T., Lyon S. R., and DeLong, J. P. (2022). FoRAGE Database: A Compilation of Functional Responses for Consumers and Parasitoids. Ecology 103(7): e3706. https://doi.org/10.1002/ecy.3706
FoRAGE database V5 (2024). https://doi.org/10.5063/F1RX99KB
data(df_Sentis_et_al_2017_GLOBAL_CHANGE_BIOLOGY) head(df_Sentis_et_al_2017_GLOBAL_CHANGE_BIOLOGY)data(df_Sentis_et_al_2017_GLOBAL_CHANGE_BIOLOGY) head(df_Sentis_et_al_2017_GLOBAL_CHANGE_BIOLOGY)
Contains Stan function of the same name as character string. Uses numerical solution of the 2-prey ODE
to compute number of eaten prey, see Rosenbaum et al. (2024).
MS_Type2H_dyn_codeMS_Type2H_dyn_code
Usage in brms formula:~ MS_Type2H_dyn(N0, N0.alt, ID, P, Time, a1, a2, h1, h2)N0 initial number of focal prey species N0.alt initial number of alternative prey species ID ID of focal species (1 or 2) P number of predators Time duration of the experiment a1 attack rate for prey species 1 a2 attack rate for prey species 2 h1 handling time for prey species 1 h2 handling time for prey species 2
Requires the data to be in a specific "long" format. Use the function
convert_2sp_to_long() to transform from a dataframe with columns
N01, N02, NE1, NE2
Number of eaten prey
Rosenbaum, B., Li, J., Hirt, M. R., Ryser, R., & Brose, U. (2024). Towards understanding interactions in a complex world: Design and analysis of multi-species functional response experiments. Methods in Ecology and Evolution, 15, 1704-1719. https://doi.org/10.1111/2041-210X.14372
Contains Stan function of the same name as character string. Uses numerical solution of the 2-prey ODE
to compute number of eaten prey, see Rosenbaum et al. (2024).
MS_Type3H_dyn_codeMS_Type3H_dyn_code
Usage in brms formula:~ MS_Type3H_dyn(N0, N0.alt, ID, P, Time, b1, b2, h1, h2, q)N0 initial number of focal prey species N0.alt initial number of alternative prey species ID ID of focal species (1 or 2) P number of predators Time duration of the experiment b1 attack coefficient for prey species 1 b2 attack coefficient for prey species 2 h1 handling time for prey species 1 h2 handling time for prey species 2 q attack rate exponent
Requires the data to be in a specific "long" format. Use the function
convert_2sp_to_long() to transform from a dataframe with columns
N01, N02, NE1, NE2
Number of eaten prey
Rosenbaum, B., Li, J., Hirt, M. R., Ryser, R., & Brose, U. (2024). Towards understanding interactions in a complex world: Design and analysis of multi-species functional response experiments. Methods in Ecology and Evolution, 15, 1704-1719. https://doi.org/10.1111/2041-210X.14372
Contains Stan function of the same name as character string. Uses numerical solution of the 2-prey ODE
to compute number of eaten prey, see Rosenbaum et al. (2024).
MS_TypeY_dyn_codeMS_TypeY_dyn_code
Usage in brms formula:~ MS_TypeY_dyn(N0, N0.alt, ID, P, Time, a1, a2, h1, h2, w1, r)N0 initial number of focal prey species N0.alt initial number of alternative prey species ID ID of focal species (1 or 2) P number of predators Time duration of the experiment a1 attack rate for prey species 1 a2 attack rate for prey species 2 h1 handling time for prey species 1 h2 handling time for prey species 2 w1 preference weight for species 1 in multi-prey r additional exponent in multi-prey only
Requires the data to be in a specific "long" format. Use the function
convert_2sp_to_long() to transform from a dataframe with columns
N01, N02, NE1, NE2
Number of eaten prey
Rosenbaum, B., Li, J., Hirt, M. R., Ryser, R., & Brose, U. (2024). Towards understanding interactions in a complex world: Design and analysis of multi-species functional response experiments. Methods in Ecology and Evolution, 15, 1704-1719. https://doi.org/10.1111/2041-210X.14372
Contains Stan function of the same name as character string. Uses numerical solution of the 2-prey ODE
to compute number of eaten prey, see Rosenbaum et al. (2024).
MS_TypeZ_dyn_codeMS_TypeZ_dyn_code
Usage in brms formula:~ MS_TypeZ_dyn(N0, N0.alt, ID, P, Time, b1, b2, h1, h2, w1, q, r)N0 initial number of focal prey species N0.alt initial number of alternative prey species ID ID of focal species (1 or 2) P number of predators Time duration of the experiment b1 attack coefficient for prey species 1 b2 attack coefficient for prey species 2 h1 handling time for prey species 1 h2 handling time for prey species 2 w1 preference weight for species 1 in multi-prey q attack rate exponent r additional exponent in multi-prey only
Requires the data to be in a specific "long" format. Use the function
convert_2sp_to_long() to transform from a dataframe with columns
N01, N02, NE1, NE2
Number of eaten prey
Rosenbaum, B., Li, J., Hirt, M. R., Ryser, R., & Brose, U. (2024). Towards understanding interactions in a complex world: Design and analysis of multi-species functional response experiments. Methods in Ecology and Evolution, 15, 1704-1719. https://doi.org/10.1111/2041-210X.14372
Contains Stan function of the same name as character string. Uses analytical solution (exponential function) of the ODE
to compute number of eaten prey.
Type1_dyn_codeType1_dyn_code
Usage in brms formula:~ Type1_dyn(N, P, Time, a)N initial number of prey P number of predators Time duration of the experiment a attack rate
Number of eaten prey
Contains Stan function of the same name as character string. Number of eaten prey:
Type1_fix_codeType1_fix_code
Usage in brms formula:~ Type1_fix(N, P, Time, a)N initial number of prey P number of predators Time duration of the experiment a attack rate
Number of eaten prey
Contains Stan function of the same name as character string. Uses analytical solution of the Beddington-DeAngelis model
to compute number of eaten prey. Rogers random predator equation with LambertW function is used with modified attack rates. Predator interference affects attack rates only.
Type2BD_dyn_codeType2BD_dyn_code
Usage in brms formula:~ Type2BD_dyn(N, P, Time, a, h, c)N initial number of prey P number of predators Time duration of the experiment a attack rate for P=1 h handling time c predator interference coefficient
Number of eaten prey
Contains Stan function of the same name as character string. Uses analytical solution of the Crowley-Martin model
to compute number of eaten prey. Rogers random predator equation with LambertW function is used with modified attack rates and handling times. Predator interference affects attack rates and handling times, both.
Type2CM_dyn_codeType2CM_dyn_code
Usage in brms formula:~ Type2CM_dyn(N, P, Time, a, h, c)N initial number of prey P number of predators Time duration of the experiment a attack rate for P=1h handling time c predator interference coefficient
Number of eaten prey
Contains Stan function of the same name as character string. Uses analytical solution (Rogers random predator equation with LambertW function) of the ODE
to compute number of eaten prey.
Type2H_dyn_codeType2H_dyn_code
Usage in brms formula:~ Type2H_dyn(N, P, Time, a, h)N initial number of prey P number of predators Time duration of the experiment a attack rate h handling time
Number of eaten prey
Contains Stan function of the same name as character string. Number of eaten prey:
Type2H_fix_codeType2H_fix_code
Usage in brms formula:~ Type2H_fix(N, P, Time, a, h)N initial number of prey P number of predators Time duration of the experiment a attack rate h handling time
Number of eaten prey
Contains Stan function of the same name as character string. Uses analytical solution of the Hassell-Varley model
to compute number of eaten prey. Rogers random predator equation with LambertW function is used with modified attack rates. Predator interference affects attack rates only.
Type2HV_dyn_codeType2HV_dyn_code
Usage in brms formula:~ Type2HV_dyn(N, P, Time, a, h, c)N initial number of prey P number of predators Time duration of the experiment a attack rate for P=1 h handling time c predator interference coefficient
Number of eaten prey
Contains Stan function of the same name as character string. Uses numerical solution of the ODE
to compute number of eaten prey.
Type3GenH_dyn_codeType3GenH_dyn_code
Usage in brms formula:~ Type3GenH_dyn(N, P, Time, b, h, q)N initial number of prey P number of predators Time duration of the experiment b attack coefficient q attack exponent h handling time
Number of eaten prey
Contains Stan function of the same name as character string. Number of eaten prey:
Type3GenH_fix_codeType3GenH_fix_code
Usage in brms formula:~ Type3GenH_fix(N, P, Time, b, h, q)N initial number of prey P number of predators Time duration of the experiment b attack coefficient q attack exponent h handling time
Number of eaten prey
Contains Stan function of the same name as character string. Uses numerical solution of the generalized type 3 ODE with an additional mortality term
to compute number of eaten / dead prey. It can compute predictions for feeding
trials (observations with P>0) and also control treatments (P=0),
for which the ODE reduces to
The exponent q can be fixed for fitting type 2 responses (q=0) or
type 3 responses (q=1), which both do not have an analytical solution
with additional and prey mortality have to be predicted using the ODE.
Type3GenH_mort_dyn_codeType3GenH_mort_dyn_code
Usage in brms formula:~ Type3GenH_dyn(N, P, Time, b, h, q, m)N initial number of prey P number of predators Time duration of the experiment b attack coefficient q attack exponent h handling time m mortality rate
Type 2 functional response: ~ Type3GenH_dyn(N, P, Time, a, h, 0, m)
Type 3 functional response: ~ Type3GenH_dyn(N, P, Time, b, h, 1, m)
Number of eaten prey
Contains Stan function of the same name as character string. Uses analytical solution (quadratic equation) of the ODE
to compute number of eaten prey.
Type3H_dyn_codeType3H_dyn_code
Usage in brms formula:~ Type3H_dyn(N, P, Time, b, h)N initial number of prey P number of predators Time duration of the experiment b attack coefficient h handling time
Number of eaten prey
Contains Stan function of the same name as character string. Number of eaten prey:
Type3H_fix_codeType3H_fix_code
Usage in brms formula:~ Type3H_fix(N, P, Time, b, h)N initial number of prey P number of predators Time duration of the experiment b attack coefficient h handling time
Number of eaten prey
Contains Stan function of the same name as character string. Uses numerical solution of the (generalized) Beddington-DeAngelis model
to compute number of eaten prey. Predator interference affects attack rates only.
TypeGenBD_dyn_codeTypeGenBD_dyn_code
The exponent q can be fixed for fitting type 2 responses (q=0) or
type 3 responses (q=1).
Usage in brms formula:~ TypeGenBD_dyn(N, P, Time, b, h, q, c)N initial number of prey P number of predators Time duration of the experiment b attack coefficient for P=1 q attack exponent h handling time c predator interference coefficient
Type 2 functional response: ~ TypeGenBD_dyn(N, P, Time, a, h, 0, c)
Type 3 functional response: ~ TypeGenBD_dyn(N, P, Time, b, h, 1, c)
Number of eaten prey
Contains Stan function of the same name as character string. Uses numerical solution of the (generalized) Crowley-Martin model
to compute number of eaten prey. Predator interference affects attack rates and handling times, both.
TypeGenCM_dyn_codeTypeGenCM_dyn_code
The exponent q can be fixed for fitting type 2 responses (q=0) or
type 3 responses (q=1).
Usage in brms formula:~ TypeGenCM_dyn(N, P, Time, b, h, q, c)N initial number of prey P number of predators Time duration of the experiment b attack coefficient for P=1q attack exponent h handling time c predator interference coefficient
Type 2 functional response: ~ TypeGenCM_dyn(N, P, Time, a, h, 0, c)
Type 3 functional response: ~ TypeGenCM_dyn(N, P, Time, b, h, 1, c)
Number of eaten prey
Contains Stan function of the same name as character string. Uses numerical solution of the (generalized) Hassell-Varley model
to compute number of eaten prey. Predator interference affects attack rates only.
TypeGenHV_dyn_codeTypeGenHV_dyn_code
The exponent q can be fixed for fitting type 2 responses (q=0) or
type 3 responses (q=1).
Usage in brms formula:~ TypeGenHV_dyn(N, P, Time, b, h, q, c)N initial number of prey P number of predators Time duration of the experiment b attack coefficient for P=1 q attack exponent h handling time c predator interference coefficient
Type 2 functional response: ~ TypeGenHV_dyn(N, P, Time, a, h, 0, c)
Type 3 functional response: ~ TypeGenHV_dyn(N, P, Time, b, h, 1, c)
Number of eaten prey